@@ -15,7 +15,7 @@ meechua_reg<-function(x){
 
   results <- ldply(models,function(i)coef(summary(i)))
   se<-results[,"Std. Error"]
-  se_after<- se[seq(1,length(se),2)]
+  se.after<- se[seq(1,length(se),2)]
 
   Variable<-rep(c("Before","Intercept"),times=101)
   res_model_tab<-cbind(Variable,results)
@@ -23,7 +23,7 @@ meechua_reg<-function(x){
 
   models<<-models
   mod_coef<<-mod_coef
-  se_after<<-se_after
+  se.after<<-se.after
 
   formattable(res_model_tab,
               align =c("l","c","c","c","c","r"),
